# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-10-25 16:09
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_core', '0004_load_skills_and_causes'),
        ('ovp_projects', '0002_auto_20161019_1557'),
    ]

    operations = [
        migrations.AddField(
            model_name='project',
            name='causes',
            field=models.ManyToManyField(to='ovp_core.Cause'),
        ),
        migrations.AddField(
            model_name='project',
            name='description',
            field=models.TextField(blank=True, max_length=160, null=True, verbose_name='Short description'),
        ),
        migrations.AddField(
            model_name='project',
            name='details',
            field=models.TextField(default='', max_length=3000, verbose_name='Details'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='project',
            name='googleaddress',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='ovp_core.GoogleAddress'),
        ),
        migrations.AddField(
            model_name='project',
            name='skills',
            field=models.ManyToManyField(to='ovp_core.Skill'),
        ),
    ]
